pymodaq_plugins_avantes
#######################

.. image:: https://img.shields.io/pypi/v/pymodaq_plugins_avantes.svg
   :target: https://pypi.org/project/pymodaq_plugins_avantes/
   :alt: 0.1

.. image:: https://readthedocs.org/projects/pymodaq/badge/?version=latest
   :target: https://pymodaq.readthedocs.io/en/stable/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/PyMoDAQ/pymodaq_plugins_avantes/workflows/Upload%20Python%20Package/badge.svg
   :target: https://github.com/PyMoDAQ/pymodaq_plugins_avantes
   :alt: Publication Status

.. image:: https://github.com/PyMoDAQ/pymodaq_plugins_avantes/actions/workflows/Test.yml/badge.svg
    :target: https://github.com/PyMoDAQ/pymodaq_plugins_avantes/actions/workflows/Test.yml


Authors
=======

* Bernhard Lang  (bernhard.lang@unige.ch)
* Eric Studemann (eric.studemann@unige.ch)


Instruments
===========

Viewer1D
++++++++

* **avantes**: control of an Avantes AvaSpec ULS2048CL EVO spectrometer

Installation instructions
=========================

* PyMoDAQ 5.0.1
* tested: Debian Linux 11/12
* Drivers / binaries needed from Avantes
   * Linux: libavs.so
   * Windows: avaspecx64.dll
   * MacOS: libavs.dylib
   * any: avaspec.py
